/*
 * Copyright (c) 2023 VMware Carbon Black, all rights reserved
 */

package poke

import (
	"bytes"
	"io"
	"log"
	"net/http"
	"os"
	"testing"

	"gitlab.bit9.local/psc/platform/ems/hello/last-contact-updater/internal/logger" //nolint:goimports  // this is ours
)

func getEndpoint() string {
	if os.Getenv("IS_LOCAL_TEST") == "" {
		return "http://localhost:5004/health_check"
	}
	return "http://ems-last-contact-updater:5004/health_check"
}

func TestHealthCheck(t *testing.T) {
	hf := logger.HeaderFunc("TestHealthCheck")
	defer hf()

	client := http.DefaultClient
	healthCheckRequest, _ := http.NewRequest("GET", getEndpoint(), http.NoBody)
	response, err := client.Do(healthCheckRequest)
	if err != nil {
		t.Fatalf("Health check test failed, %v", err)
	}
	//goland:noinspection GoUnhandledErrorResult
	defer response.Body.Close()

	var buffer bytes.Buffer
	_, err = io.Copy(&buffer, response.Body)
	if err != nil {
		t.Fatalf("Response body read failure")
	}
	log.Printf("GOT: %v", response)
	if response.StatusCode != 200 {
		t.Fatalf("Health check test failed %d %s", response.StatusCode, buffer.String())
	}
}
